      FUNCTION ABSO3(T,P,O3N,F)
C     3/10/89  PWR
c     8/6/15  read line parameters from a file
c     7/23/18 increased MAXLINES
c     9/2/21  Voigt lineshape
C     phil.rosenkranz@alum.mit.edu
C
C      ABSO3 = POWER ABSORPTION COEFF. (NEPERS/KM) IN THE ATMOSPHERE DUE TO 
C            SELECTED LINES OF OZONE, READ FROM FILE o3_list.asc
C            Multiply ABSO3 by 4.343 to obtain dB/km.
C      T = TEMPERATURE (DEG K)
C      P = TOTAL PRESSURE (MILLIBARS)
C      O3N = OZONE NUMBER DENSITY (MOLECULES/M**3)
C      F = FREQUENCY (GHZ)
C
c     Line parameters will be read from file o3_list.asc

      IMPLICIT NONE
      INTEGER NLINES,I,MAXLINES
      PARAMETER (MAXLINES=500)
      REAL ABSO3,T,P,O3N,F
      REAL S1(MAXLINES),B(MAXLINES),W(MAXLINES),FL(MAXLINES),X(MAXLINES)
      REAL SR(MAXLINES),WAIR,REFTLINE,DEN,TI,TI2,QVINV,SUMM,
     & WIDTHC,BETAD
      DOUBLE PRECISION ARG1,ARG2,S
      DOUBLE COMPLEX DCERROR
      SAVE INIT,REFTLINE,NLINES,S1,B,W,FL,X,SR
      LOGICAL INIT
      CHARACTER*4 HEAD
      DATA INIT/.TRUE./

C   initialization section
      IF(INIT) THEN
        OPEN(80,FILE='o3_list.asc',
     &   STATUS='OLD',FORM='FORMATTED')
        REFTLINE = 296. !reference T for lines
        READ(80,1) HEAD !header for linedata
1       FORMAT(A4)
        DO I=1,MAXLINES
C    LINE INTENSITIES FROM HITRAN INCLUDE ISOTOPOMER ABUNDANCE
C    read line parameters; units: GHz, Hz*cm^2, MHz/mb
          READ(80,2) FL(i),S1(i),B(i),WAIR,X(i),SR(i)
2         FORMAT(4X,F12.4,E12.4,2F7.3,F6.2,F8.4)
          IF(FL(I) .LE. 0.) GOTO 10
          NLINES = I
          W(I) = WAIR/1000. !GHz/mb
        END DO
        WRITE(*,*) 'WARNING: maximum O3 lines reached'
10      CONTINUE
        CLOSE(80)
        INIT = .FALSE.
        WRITE(*,*) NLINES,' O3 lines read'
      ENDIF
C
c   test for zero ozone
      IF(O3N.LE.0.) THEN
        ABSO3 = 0.
        RETURN
      ENDIF
c
c  computation of absorption
      DEN = 1.E-6*O3N
      TI = REFTLINE/T
      TI2 = TI**2.5
      QVINV = 1. -EXP(-1008./T)
C  ADD RESONANCES WITHIN 1 GHz OF F.  MOST OF THE OZONE IS IN THE 
C  STRATOSPHERE, SO LINES ARE RELATIVELY NARROW.
      SUMM = 0.
      DO I=1,NLINES
       IF( FL(I).GT.(F+1.) ) GOTO 20
       IF( FL(I).GE.(F-1.) ) THEN
        WIDTHC = W(I)*P*TI**X(I) !collisional halfwidth
c .62065E-7 = sqrt(2k/m)/c
        BETAD = .62065E-7*FL(I)*SQRT(T) !doppler broadening
        ARG1 = (FL(I)-F)/BETAD
        ARG2 = WIDTHC/BETAD
        S = S1(I)*EXP(B(I)*(1.-TI))
        SUMM = SUMM + S*DREAL(DCERROR(ARG1,ARG2))/BETAD
       ENDIF
      END DO
c   .56419 = 1/sqrt(pi)
20    ABSO3 = .56419E-4*SUMM*QVINV*TI2*DEN
      RETURN
      END
