      DOUBLE COMPLEX FUNCTION DCERROR(X,Y)
c
C  SIXTH-ORDER APPROX TO THE COMPLEX ERROR FUNCTION OF z=X+iY.
C  CERROR = exp(-z^2)erfc(-iz)
C  This version is double precision and valid in all quadrants.
C  REFERENCE FOR EQUATIONS:
C      HUI, ARMSTRONG AND WRAY, JQSRT V.19, P.509-516 (1978).
C
C     P. ROSENKRANZ  12/11/2018
C
      IMPLICIT NONE
      DOUBLE PRECISION X,Y,a(0:6),b(0:6)
      DOUBLE COMPLEX ASUM,BSUM,ZH,w
      data a/122.607931777104326d0, 214.382388694706425d0,
     & 181.928533092181549d0, 93.155580458138441d0,
     & 30.180142196210589d0, 5.912626209773153d0,
     & 0.564189583562615d0/
      data b/122.607931773875350d0, 352.730625110963558d0,
     & 457.334478783897737d0, 348.703917719495792d0,
     & 170.354001821091472d0, 53.992906912940207d0,
     & 10.479857114260399d0/

c  compute w in quadrants 1 or 2
c  from eqs.(13), w(z) = [w(-z*)]*
c  expansion in terms of ZH results in conjugation of w when X changes sign.
      ZH = DCMPLX(DABS(Y),-X)
      ASUM = (((((a(6)*ZH+a(5))*ZH+a(4))*ZH+
     & a(3))*ZH+a(2))*ZH+a(1))*ZH+a(0)
      BSUM = ((((((ZH+b(6))*ZH+b(5))*ZH+b(4))*ZH+
     & b(3))*ZH+b(2))*ZH+b(1))*ZH+b(0)
      w = ASUM/BSUM
c
      if(Y.ge.0.d0) then
        DCERROR = w !for quadrants 1&2
      else
c  from eqs.(13), w(z) = 2exp(-z^2)-[w(z*)]*
        DCERROR = 2.d0*cdexp(-dcmplx(X,Y)**2) - dconjg(w) ! for quadrants 3&4
      endif
      RETURN
      END

