      SUBROUTINE H2OCON(NFREQ,FREQ,TEMP,CS)
C NAME- h2ocon.f    LANGUAGE- FORTRAN 77
c fit a curve to mtckd 4.1 self-continuum
c adapted from mt_ckd_h2o_module.f90
C March 20, 2023
c
      implicit none
C  CALLING SEQUENCE PARAMETERS:
C             NAME     UNITS           I/O  DESCRIPTION      VALID RANGE
      INTEGER NFREQ    !                I  number of freq & cs
      REAL FREQ(NFREQ) !GHz             I  frequency          0 to 1200
      REAL TEMP        !Kelvin          I  temperature
      REAL CS(NFREQ) !1/(km(GHz*hPa)^2) O  self-continuum coeff. at TEMP
c
c  Local variables:
      integer nf,i,j
      parameter (nf=5)
      real deltaf,selfcon(0:nf),selftexp(0:nf)
      real P,C,B,B1,B2,theta,A(-1:NF),FJ
      data DELTAF/ 299.792458/ ! 10 cm-1
c At T=296K,ref_press 1013hPa and wavenumbers 0, 10, 20, 30, 40, 50 cm-1 :
      data selfcon/ 2.877e-21, 2.855e-21, 2.731e-21, 2.49e-21,
     & 2.178e-21, 1.863e-21/ !cm**2/molecule cm-1
      data selftexp/ 6.413, 6.414, 6.275, 6.049, 5.789, 5.557/
c above coeffs are the same in mt-ckd_4.3 (4/17/2024)
c
c  convert to neper km^-1 (GHz hPa)^-2  
      Theta = 296./temp
      DO J=0,NF
       A(J) = 6.532E12*SELFCON(J)*THETA**(SELFTEXP(J)+3.)
      END DO
      A(-1) = A(1)
      DO I = 1,NFREQ ! interpolate to the desired frequencies
      FJ = FREQ(I)/DELTAF
      J = FJ
      J = MIN0(J,NF-2)
      P = FJ - FLOAT(J)
      C = (3.-2.*P)*P*P
      B = 0.5*P*(1.-P)
      B1 = B*(1.-P)
      B2 = B*P 
      CS(I) = -A(J-1)*B1+A(J)*(1.-C+B2)+A(J+1)*(C+B1)-A(J+2)*B2
      END DO
      RETURN
      END

