      SUBROUTINE LINLIN(IUNIT,STRINGX,OVALX,NDIVX,DELTAX,PX,NDLX,FORMX,
     & STRINGY,OVALY,NDIVY,DELTAY,PY,NDLY,FORMY)
C
c Copyright © April 8, 2023 P.W. Rosenkranz; Creative Commons license CC BY-SA

C   PROGRAMMER- phil.rosenkranz@alum.mit.edu
C
C   FUNCTION- 
C     DRAWS AN ENCLOSED AND LABELED GRAPH WITH LINEAR (1 TIC/DIVISION)
C     SCALES ON BOTH AXES.
C     TIC MARKS APPEAR ON ALL 4 SIDES OF THE BOX.
C     ALSO DEFINES VARIABLES IN COMMON /GRCOM/ FOR USE BY PLOTLINE,
C     PLOTPT, ETC.
C
C   CALLING SEQUENCE PARAMETERS (ALL INPUTS)-
C
C   NAME   TYPE    DESCRIPTION
C
C  IUNIT   INT     FORTRAN UNIT FOR GRAPH (OPENED IN MAIN PROGRAM)
C  STRINGX CHAR    TITLE FOR X AXIS, TERMINATED WITH ?
C  OVALX   REAL    USER VALUE OF X ORIGIN (LLC)
C  NDIVX   INT     NUMBER OF DIVISIONS ALONG X AXIS
C  DELTAX  REAL    USER UNITS/DIVISION - POSITIVE/NEGATIVE IF
C                   INCREASING/DECREASING TOWARD RIGHT
C  PX      REAL    PS UNITS/DIVISION ALONG X AXIS (ZERO FOR LETTER-PAGE WIDTH)
C  NDLX    INT     NO. OF DIVISIONS BETWEEN LABELS FOR X AXIS
C  FORMX   CHAR    FORMAT SPEC. (F-TYPE) FOR X-AXIS 
C                   EX: '(F7.3)' MAX.WIDTH = 7
C  STRINGY CHAR    TITLE FOR Y AXIS, TERMINATED WITH ?
C  OVALY   REAL    USER VALUE OF Y ORIGIN (LLC)
C  NDIVY   INT     NUMBER OF DIVISIONS ALONG Y AXIS
C  DELTAY  REAL    USER UNITS/DIVISION - POSITIVE/NEGATIVE IF
C                   INCREASING/DECREASING TOWARD TOP
C  PY      REAL    PS UNITS/DIVISION ALONG Y AXIS (ZERO FOR LETTER-PAGE HEIGHT)
C  NDLY    INT     NO. OF DIVISIONS BETWEEN LABELS FOR Y AXIS
C  FORMY   CHAR    FORMAT SPEC. (F-TYPE) FOR Y-AXIS 
C                   EX: '(F7.3)' MAX.WIDTH = 7
C
C   SUBROUTINES CALLED- SETUPPS, RECTANG, LINE, TEXTOUT
C***********************************************************************
C  12/8/18 moved axis labeling to beginning
c  12/2/22 IUNIT added to arg list
C  4/8/23 zero option for page-size plot
C
      include 'common.inc'
      CHARACTER*64 STRINGX,STRINGY
      CHARACTER*8 BUFFER8
      CHARACTER*7 BUFFER
      EQUIVALENCE (BUFFER8,BUFFER)
      REAL OVALX,OVALY,DELTAX,DELTAY,X1,X2,Y1,Y2,CH,CW,PX,PY,PXL,PYL
      INTEGER NDIVX,NDIVY,NDLX,NDLY,IFS
      CHARACTER*6 FORMX,FORMY
C
C     INITIALIZE AND SET PARAMETERS
C     THIS VERSION FOR HARDWARE Y VALUES INCREASING VERTICALLY
C
      NUNIT = IUNIT
      IFS = 18 ! font size
      ch = 10. ! character height in PS units
      cw = 11. ! character spacing in PS units
      CH2 = CH/2.
      FLT = CH2                    !length of tics
      FWX = 7.                     !max format field width
      FWY = 7.
      UVALX = OVALX                ! USER COORD OF LLC
      UVALY = OVALY                ! USER COORD OF LLC
      IF(PX.GT.0.) THEN
       PXL = PX
       FNX = NDIVX*PXL              ! width of frame
       ORX = 2.*CH +FWY*CW          ! PHYS COORD OF LLC
       FMX = ORX + FNX              ! right side of frame
       XMAX = FMX + FWX*CW/2. + CW  ! LARGEST X COORD USED
       XMIN = 0.                    ! smallest X coord
      ELSE
       XMAX = 585.                  ! 8 1/8"
       XMIN = 27.                   ! 3/8"
       FMX = XMAX - FWX*CW/2. - CW
       ORX = XMIN + 2.*CH +FWY*CW  
       FNX = FMX - ORX
       PXL = FNX/FLOAT(NDIVX)
      ENDIF
      SCALEX = DELTAX/PXL           ! SCALE FACTOR (USER/PHYS)
      IF(PY.GT.0.) THEN
       PYL = PY
       FNY = NDIVY*PYL              ! height of frame
       ORY = 5.*CH                  ! PHYS COORD OF LLC
       FMY = ORY + FNY              ! top of frame
       YMAX = FMY + 2.*CH           ! LARGEST Y COORD USED
       YMIN = 0.                    ! smallest Y coord
      ELSE
       YMAX = 765.                  ! 10 5/8"
       YMIN = 27.                   ! 3/8"
       FMY = YMAX - 2.*CH 
       ORY = YMIN + 5.*CH
       FNY = FMY - ORY
       PYL = FNY/FLOAT(NDIVY)
      ENDIF
      SCALEY = DELTAY/PYL           ! SCALE FACTOR (USER/PHYS)
      CALL SETUPPS(IFS)
C
C     WRITE X-AXIS STRING
      XORIG_LABEL = ORX + FNX/2.
      YORIG_LABEL = ORY - 4.*CH
      CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,CW,STRINGX,'?',0)
C     WRITE Y-AXIS STRING
      XORIG_LABEL = ORX - FWY*CW - .5*CH
      YORIG_LABEL = ORY + FNY/2.
      CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,CW,STRINGY,'?',90)
c
C     DRAW BOX
      CALL RECTANG(ORX,ORY,FMX,FMY,.FALSE.)
C
C     DRAW TIC MARKS FOR X-AXIS
      DO I=1,NDIVX
      X1 = ORX +I*PXL
      Y1 = ORY +FLT
      Y2 = ORY
      CALL LINE(X1,Y1,X1,Y2)
      Y1 = FMY
      Y2 = Y1 - FLT
      CALL LINE(X1,Y1,X1,Y2)
      END DO
C
C     LABEL TICS
      YORIG_LABEL = ORY - 2.*CH
      DO I=0,NDIVX,NDLX
      XORIG_LABEL = ORX - (FWX*CW +CW)/2.  + I*PXL
      UX = OVALX + I*DELTAX
      BUFFER8 = '????????'
      WRITE(BUFFER,FORMX) UX
      CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,0.,BUFFER8,'?',0)
      END DO
C
C     DRAW TIC MARKS FOR Y-AXIS
      DO I=1,NDIVY
      Y1 = ORY + I*PYL
      X1 = ORX
      X2 = ORX +FLT
      CALL LINE(X1,Y1,X2,Y1)
      X2 = FMX
      X1 = X2 - FLT
      CALL LINE(X1,Y1,X2,Y1)
      END DO
C
C     LABEL TICS
      XORIG_LABEL = ORX -(FWY+.3)*CW 
      DO I=0,NDIVY,NDLY
      YORIG_LABEL = ORY -CH2 +I*PYL
      UY = OVALY + I*DELTAY
      BUFFER8 = '????????'
      WRITE(BUFFER,FORMY) UY
      CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,0.,BUFFER8,'?',0)
      END DO
      RETURN
      END
