      SUBROUTINE LINLOG(IUNIT,STRINGX,OVALX,NDIVX,DELTAX,PX,NDLX,FORMX,
     & STRINGY,OVALY,DECY,PY,FORMY)
C
c Copyright © April 11, 2023 P.W. Rosenkranz; Creative Commons license CC BY-SA

C   PROGRAMMER- phil.rosenkranz@alum.mit.edu

C   FUNCTION- 
C     DRAWS AN ENCLOSED AND LABELED GRAPH WITH LINEAR (1 TIC/DIVISION)
C     SCALE ON X-AXIS AND LOG (10 TICS/DIVISION) SCALE ON Y-AXIS.
C     TIC MARKS APPEAR ON ALL 4 SIDES OF THE BOX.
C     ALSO DEFINES VARIABLES IN COMMON /GRCOM/ FOR USE BY PLOTLINE,
C     PLOTPT, ETC.
C
C   CALLING SEQUENCE PARAMETERS (ALL INPUTS)-
C
C   NAME   TYPE    DESCRIPTION
C
C  IUNIT   INT     FORTRAN UNIT FOR GRAPH (OPENED IN MAIN PROGRAM)
C  STRINGX CHAR    TITLE FOR X AXIS, TERMINATED WITH ?
C  OVALX   REAL    USER VALUE OF X ORIGIN (LLC)
C  NDIVX   INT     NUMBER OF DIVISIONS ALONG X AXIS
C  DELTAX  REAL    USER UNITS/DIVISION - POSITIVE/NEGATIVE IF
C                   INCREASING/DECREASING TOWARD RIGHT
C  PX      REAL    PS UNITS/DIVISION ALONG X AXIS (ZERO FOR LETTER-PAGE WIDTH)
C  NDLX    INT     NO. OF DIVISIONS BETWEEN LABELS FOR X AXIS
C  FORMX   CHAR    FORMAT SPEC. (F-TYPE) FOR X-AXIS 
C                   EX: '(F7.3)' MAX.WIDTH = 7
C  STRINGY CHAR    TITLE FOR Y AXIS, TERMINATED WITH ?
C  OVALY   REAL    ALOG(BASE10) OF USER VALUE AT Y ORIGIN
C  DECY    REAL    NUMBER OF DECADES ALONG Y AXIS - POSITIVE/NEGATIVE
C                  FOR LOG SCALE INCREASING/DECREASING TOWARD TOP
C  PY      REAL    PS UNITS/DECADE ALONG Y-AXIS (ZERO FOR LETTER-PAGE HEIGHT)
C  FORMY   CHAR    FORMAT SPEC. FOR Y-AXIS, 
C                  INT.EXPONENT-TYPE EXAMP. '(I3)' MAX.WIDTH = 3
C                  FLOATING-TYPE EXAMP. '(F7.3)' MAX.WIDTH = 7
C
C   SUBROUTINES CALLED- SETUPPS, RECTANG, LINE, TEXTOUT
C***********************************************************************
C  12/13/18 moved axis labeling to beginning
c  12/2/22 IUNIT added to arg list
C  4/11/23 zero option for page-size plot

      include 'common.inc'
      CHARACTER*64 STRINGX,STRINGY
      CHARACTER*8 BUFFER8
      CHARACTER*7 BUFFER
      EQUIVALENCE (BUFFER8,BUFFER)
      CHARACTER*6 FORMX,FORMY
      REAL OVALX,OVALY,DELTAX,DECY,X1,X2,Y1,Y2,CH,CW,PX,PY,PXL,PYL
      INTEGER LOVALY,ITICY,IFS,LTOP
C
C     INITIALIZE AND SET PARAMETERS
C     THIS VERSION FOR HARDWARE Y VALUES INCREASING VERTICALLY
C
      NUNIT = IUNIT
      IFS = 18 ! font size
      ch = 10. ! character height in PS units
      cw = 11. ! character spacing in PS units
      CH2 = CH/2.
      FLT = CH2                    !length of tics
      FWX = 7.                     !max format field width
      IF(INDEX(FORMY,'I').EQ.0 .AND. INDEX(FORMY,'i').EQ.0) THEN
       FWY = 7.
      ELSE
       FWY = 3.
      ENDIF
      LOVALY = INT(OVALY)
      FY = OVALY - LOVALY
      LTOP = INT(OVALY+DECY)
      FTOP = OVALY+DECY - LTOP
      IF(FY.LT.0.) THEN
        LOVALY = LOVALY -1
        FY = FY +1.
      ENDIF
      ITICY = INT(10.**FY) + 1
      ADECY = ABS(DECY)
      SGY = SIGN(1.,DECY)
      UVALX = OVALX                ! USER COORD OF LLC
      UVALY = OVALY                ! USER COORD OF LLC
      IF(PX.GT.0.) THEN
       PXL = PX
       FNX = NDIVX*PXL              ! width of frame
       ORX = 2.*CH + (FWY+3.)*CW    ! PHYS COORD OF LLC
       FMX = ORX + FNX              ! right side of frame
       XMAX = FMX + FWX*CW/2. + CW  ! LARGEST X COORD USED
       XMIN = 0.                    ! smallest X coord
      ELSE
       XMAX = 585.                  ! 8 1/8"
       XMIN = 27.                   ! 3/8"
       FMX = XMAX - FWX*CW/2. - CW
       ORX = XMIN + 2.*CH + (FWY+3.)*CW
       FNX = FMX - ORX
       PXL = FNX/FLOAT(NDIVX)
      ENDIF
      SCALEX = DELTAX/PXL           ! SCALE FACTOR (USER/PHYS)
      IF(PY.GT.0.) THEN
       PYL = PY
       FNY = ADECY*PYL              !height of frame
       ORY = 5.*CH                  ! PHYS COORD OF LLC
       FMY = ORY + FNY              ! top of frame
       YMAX = FMY + 2.*CH           !LARGEST Y COORD USED
       YMIN = 0.                    ! smallest Y coord
      ELSE
       YMAX = 765.                  ! 10 5/8"
       YMIN = 27.                   ! 3/8"
       FMY = YMAX - 2.*CH
       ORY = YMIN + 5.*CH
       FNY = FMY - ORY
       PYL = FNY/ADECY
      ENDIF
      SCALEY = SGY/PYL              ! SCALE FACTOR (USER/PHYS)
      CALL SETUPPS(IFS)
C
C     WRITE X-AXIS STRING
      XORIG_LABEL = ORX + FNX/2.
      YORIG_LABEL = ORY - 4.*CH
      CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,CW,STRINGX,'?',0)
C     WRITE Y-AXIS STRING
      XORIG_LABEL =  ORX - (FWY+3.)*CW - .5*CH
      YORIG_LABEL = ORY + FNY/2.
      CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,CW,STRINGY,'?',90)
C
C     DRAW BOX
      CALL RECTANG(ORX,ORY,FMX,FMY,.FALSE.)
C
C     DRAW TIC MARKS ON X-AXIS
      DO I=1,NDIVX
      X1 = ORX +I*PXL
      Y1 = ORY +FLT
      Y2 = ORY
      CALL LINE(X1,Y1,X1,Y2)
      Y1 = FMY
      Y2 = Y1 - FLT
      CALL LINE(X1,Y1,X1,Y2)
      END DO
C
C     LABEL TICS
      YORIG_LABEL = ORY - 2.*CH
      DO I=0,NDIVX,NDLX
      XORIG_LABEL = ORX - (FWX*CW +CW)/2.  + I*PXL
      UX = OVALX + I*DELTAX
      BUFFER8 = '????????'
      WRITE(BUFFER,FORMX) UX
      CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,0.,BUFFER8,'?',0)
      END DO
C
C     DRAW TIC MARKS ON Y-AXIS
      A = 0.
      IF(SGY.LT.0.) A = 1.
      IF(ABS(FY).LT. .001 .AND. SGY.GT.0.) THEN  !label origin
        Y1 = ORY
        LUY = LOVALY
        GOTO 22
      ENDIF
      IF(ABS(FTOP).LT. .001 .AND. SGY.LT.0.) THEN  !label top decade
        Y1 = FMY
        LUY = LTOP
        GOTO 22
      ENDIF
15    CONTINUE
      DO J=ITICY,10
      Y1 = ORY +(A+SGY*(ALOG10(FLOAT(J))-FY))*PYL
      IF(Y1.GT.FMY) GOTO 30
      X1 = ORX
      X2 = ORX + FLT
      CALL LINE(X1,Y1,X2,Y1)
      X2 = FMX
      X1 = X2 - FLT
      CALL LINE(X1,Y1,X2,Y1)
      END DO
      ITICY = 2

C     LABEL DECADE TICS
      A = A+1.
      LUY = LOVALY + A
      IF(SGY.LT.0.) LUY = LOVALY -A +2
22    BUFFER8 = '????????'
      IF(FWY.GT.3.) THEN
       FLUY = 10.**LUY
       WRITE(BUFFER,FORMY) FLUY
       YORIG_LABEL = Y1 -CH2
      ELSE
       WRITE(BUFFER,FORMY) LUY
       YORIG_LABEL = Y1
      ENDIF
      XORIG_LABEL = ORX - FWY*CW
      CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,0.,BUFFER8,'?',0)
      IF(FWY.LE.3.) THEN
       XORIG_LABEL = XORIG_LABEL -2.*CW
       YORIG_LABEL = YORIG_LABEL - CH2
       CALL TEXTOUT(XORIG_LABEL,YORIG_LABEL,0.,'10?','?',0)
      ENDIF
      GOTO 15
30    CONTINUE
      RETURN
      END
