      SUBROUTINE PLOTLINE(XARRAY,YARRAY,LENGTH,LINESTYLE)
c   Copyright © July 14, 2018 P.W. Rosenkranz; Creative Commons license CC BY-SA
C
C   PROGRAMMER- phil.rosenkranz@alum.mit.edu
C   VERSION 2 - revised the style choices
C   
C   FUNCTION- 
C     PLOTS LINE SEGMENTS THROUGH USER POINTS DEFINED BY XARRAY
C     AND YARRAY, USING SCALE PARAMETERS SET UP BY LINLOG, ETC.
C     NOTE: IF EITHER X OR Y SCALE IS LOGARITHMIC, USER UNITS ARE
C        LOG(BASE 10) OF DATA.
C
C   CALLING SEQUENCE PARAMETERS-
C
C   NAME   TYPE  I/O    DESCRIPTION
C
C   XARRAY  R*4   I     ARRAY OF ABSCISSA VALUES IN USER UNITS
C   YARRAY  R*4   I     ARRAY OF ORDINATE VALUES IN USER UNITS
C   LENGTH  I*4   I     LENGTH OF X AND Y ARRAYS
C   LINESTYLE I*4 I     LINE STYLE:  0: SOLID LINE;  1: LONG DASHES;
C                       2: SHORT DASHES;  3: DOTTED LINE;
C                       4: DASH-DOT;  5: DASH-DOT-DOT;
C                       6: DASH-DASH-DOT; 7: DASH-DASH-DOT-DOT
C***************************************************************
      include 'common.inc'
      INTEGER*4 LENGTH,I,LINESTYLE
      LOGICAL SOLID
      REAL*4 XARRAY(LENGTH),YARRAY(LENGTH),XP,YP
      CHARACTER*17 ONOFF(7)
      DATA ONOFF/'            [8 4]',
     &           '            [4 4]',
     &           '            [1 2]',
     &           '        [6 3 1 3]',
     &           '    [6 3 1 3 1 3]',
     &           '    [6 3 6 3 1 3]',
     &           '[6 3 6 3 1 3 1 3]'/
C
C  determine line type and move to start position
      CALL CONVPT(XARRAY(1),YARRAY(1),XP,YP)
      SOLID = LINESTYLE.LE.0 .OR. LINESTYLE.GT.7
      IF(SOLID) THEN
        WRITE(NUNIT,1) XP,YP
1       FORMAT(2f10.4,' m')
      ELSE 
        WRITE(NUNIT,4) ONOFF(LINESTYLE),XP,YP
4       FORMAT(A17,' 0 d ',2f10.4,' m')
      ENDIF

C  draw line
      DO I=2,LENGTH
       CALL CONVPT(XARRAY(I),YARRAY(I),XP,YP)
       WRITE(NUNIT,2) XP,YP
2      FORMAT(2f10.4,' l')
      END DO
      WRITE(NUNIT,3)
3     FORMAT('k')
      IF(.NOT.SOLID) WRITE(NUNIT,6) !restore solid line type
6     FORMAT('[ ] 0 d')
      RETURN
      END

