c  PLOT DOWNWELLING BRIGHTNESS-TEMPERATURE SPECTRUM FROM U.S. STD. ATMOSPHERE.
c  FOR CALCULATION OF THE ZEEMAN SPLITTING, THE MAGNETIC FIELD IS CONSIDERED
C  CONSTANT OVER THE PROPAGATION PATH HERE.
C
C  9/16/2016 first version
C  2/14/18 revised TBC; using TBARRAY2 now
c  7/14/18 new call to plotline
C  10/26/18 check for number of levels in atmosphere profile
C  1/14/19 call o2absz instead of zeeman; corrected path length in call to tbmx
c  5/5/22 use findline to get line index JU
c  3/27/23 opening plot file here
C  4/25/23 revised TBARRAY2

c  SUBROUTINES CALLED: E2ROT,O2ABSZ,TBMX,TBARRAY2,LINLIN,PLOTLINE,ENDGRAPH
      IMPLICIT NONE
      INTEGER N,M,I,J,NLV,JU,MXLV
      PARAMETER (N=91,M=101)
      REAL FREQ,F1,F2,TEMP(N),PRES(N),RHO(N),O3NUM(N),CLD(N)
      REAL ANGLE,TB1,TB2,TBC,E1,E2,SECANT,H(N),PAV,TAV,ALPHA
      REAL TBv(M),TBh(M),TBlc(M),TBrc(M),ALT,TS,F(M),DELF,TBMIN,TBMAX
      REAL DELTB,BFIELD,BVEC(3),CTHN,CBTH,PHI,DS,DF,HTR,rcons,efac
      REAL OPACITY(N)
      COMPLEX GM,GPI,GP,PHASEROTFAC,TBLIN
      LOGICAL ZCALC

      rcons = .0479923
      HTR = 40. !transition altitude between zeeman region & lower atmosphere

c  READ ATMOSPHERE PROFILE
      OPEN(1,FILE='profile.dat',FORM='FORMATTED')
      DO I=1,N
       READ(1,1,end=3)  H(I),TEMP(I),PRES(I),RHO(I),O3NUM(I)
C atmospheric profile starting at surface:
C H(km), TEMP(K), PRES(mb), H2OvaporRHO(g/m**3), O3NUMdensity(molecules/m**3)
1      FORMAT(2F8.2,3E12.3)
       CLD(I) = 0.
       MXLV = I
      END DO
3     CLOSE(1)
      TS = TEMP(1)
      PHASEROTFAC = (1.,0.)
C  READ PARAMETERS FOR THE CALCULATION
      WRITE(*,*) 'ENTER MAX.ALTITUDE (km), ANGLE FROM VERTICAL (deg)'
      READ(*,*) ALT,ANGLE
      CTHN = COS(ANGLE/57.296)
      SECANT = 1./CTHN
      BFIELD = 0.
      IF(ALT.GT.HTR) THEN
        WRITE(*,*) 'ENTER AZIMUTH ANGLE OF PROPAGATION',
     &   ' (deg from north toward east)'
        READ(*,*) PHI
        WRITE(*,*) 'ENTER B-FIELD COMPONENTS:',
     & ' NORTHWARD,EASTWARD,DOWNWARD (gauss)'
        READ(*,*) BVEC
        CALL E2ROT(CTHN,PHI,BVEC,PHASEROTFAC,CBTH,BFIELD)
      ENDIF
      WRITE(*,*) 'ENTER FREQUENCY LIMITS (GHz): lower,upper'
      READ(*,*) F1,F2
      IF(F2.LE.F1) STOP
      OPEN(2,FILE='spectrum.out',FORM='FORMATTED')
      WRITE(2,*) ALT,' km ',ANGLE,' deg ',BFIELD,' gauss'
      WRITE(2,*) '      freq     TBv         TBh',
     & '         TBlin                TBrc     TBlc'
      DF = (F2-F1)/100.
      TBMIN = 500.
      TBMAX = 0.
      NLV = MXLV
      DO 30 J=1,M  !frequency loop
       FREQ = F1 + (J-1)*DF
       efac = exp(rcons*freq/2.73)
C including zero-point fluctuation in cosmic background compensates
C for non-linearity of Planck function
       TBC = .5*rcons*freq*(efac+1.)/(efac-1.)
       F(J) = FREQ
       TBLIN = 0.
       TBRC(J) = TBC
       TBLC(J) = TBC
       JU = 0
       IF(ALT.GT.HTR) CALL FINDLINE(FREQ,0.03,JU,DELF)
       ZCALC = JU.GT.0
c
       DO 20 I=MXLV,2,-1 !altitude loop; find nlv for scalar prop
        IF(H(I).GT.ALT) GOTO 20

        IF(ZCALC) THEN ! Polarized propagation
         TAV = (TEMP(I) + TEMP(I-1))/2.
         PAV = SQRT(PRES(I)*PRES(I-1))
         DS = (H(I)-H(I-1))*SECANT
         CALL O2ABSZ(TAV,PAV,FREQ,BFIELD,JU,ALPHA,GM,GPI,GP)
         CALL TBMX(TBRC(J),TBLC(J),TBLIN,DS,TAV,ALPHA,GP,GM,GPI,CBTH)
        ELSE
         NLV = I
         GOTO 25
        ENDIF

        IF(H(I-1).LE.HTR) THEN
         NLV = I-1
         GOTO 25
        ENDIF

20    CONTINUE

25    CONTINUE
C  Scalar propagation. Although TBARRAY2 can compute for multiple angles
c   and frequencies, it's used 1 freq at a time here, for compatibility
c   with the Zeeman routines.
       CALL TBARRAY2(NLV,H,TEMP,PRES,RHO,CLD,O3NUM,1,SECANT,SECANT,
     &  1,FREQ,TB1,TB2,E1,E2,OPACITY)
       TBLC(J) = TB1 + E1*TBLC(J)
       TBRC(J) = TB1 + E1*TBRC(J)
       TBLIN = E1*TBLIN
C  rotate phase to V-pol plane. note that TBv and TBh may be correlated
       TBLIN = TBLIN*PHASEROTFAC
       TBv(J) = (TBRC(J)+TBLC(J))/2. + REAL(TBLIN)
       TBh(J) = TBv(J) - 2.*REAL(TBLIN)
       TBMIN = AMIN1(TBMIN,TBv(J),TBh(J),TBRC(J),TBLC(J))
       TBMAX = AMAX1(TBMAX,TBv(J),TBh(J),TBRC(J),TBLC(J))
       WRITE(2,2) FREQ,TBv(J),TBh(J),TBLIN,TBRC(J),TBLC(J)
2      FORMAT(7F11.4)
30    CONTINUE
      CLOSE(2)

C  PLOT TB CURVES
      DELTB = (TBMAX-TBMIN)/10.
      OPEN(3,FILE='test_dn.eps',STATUS='unknown',FORM='formatted')
      CALL LINLIN(3,'FREQUENCY, GHz?',F1,5,20.*DF,80.,1,'(F7.3)',
     & 'BRIGHTNESS TEMPERATURE, K?',TBMIN,10,DELTB,40.,1,'(F7.2)')
      CALL PLOTLINE(F,TBh,M,2)
      CALL PLOTLINE(F,TBv,M,1)
      IF(ZCALC) THEN
       CALL PLOTLINE(F,TBRC,M,0)
       CALL PLOTLINE(F,TBLC,M,4)
      ENDIF
      CALL ENDGRAPH
      END

