c  PLOT UPWELLING BRIGHTNESS-TEMPERATURE SPECTRUM FROM U.S. STD. ATMOSPHERE
C  ABOVE AN OCEAN SURFACE.
c  FOR CALCULATION OF THE ZEEMAN SPLITTING, THE MAGNETIC FIELD IS CONSIDERED
C  CONSTANT OVER THE PROPAGATION PATH HERE.
c 9/14/16  first version
C  2/14/18 revised TBC; using TBARRAY2 now
c  7/14/18 new call to plotline
C  10/26/18 check for number of levels in atmosphere profile
C  11/14/18 calc. H2O integral
C  1/14/19 call o2absz instead of zeeman; corrected path length in call to tbmx
c  5/5/22 use findline to get line index JU
c  3/27/23 opening plot file here
C  7/7/23 revised call to TBARRAY2
C
      IMPLICIT NONE
      INTEGER N,M,I,J,NLV,NLVA,NLVTR,NM1,JU,MXLV
      PARAMETER (N=91,M=101)
      REAL FREQ,F1,F2,TEMP(N),PRES(N),RHO(N),O3NUM(N),CLD(N)
      REAL ANGLE,TB1,TB2,TBC,E1,E2,RV,RH,SECANT1,SECANT2,H(N),PAV,TAV
      REAL TBv(M),TBh(M),TBlc(M),TBrc(M),ALT,TS,F(M),DELF,TBMIN,TBMAX
      REAL DELTB,BFIELD,BVEC(3),CTHN,CBTH,PHI,DS,DF,HTR,rcons,efac
      REAL VINT,ALPHA,OPACITY(N)
      COMPLEX EC,GM,GPI,GP,PHASEROTFAC,TBLIN
      LOGICAL ZCALC
      rcons = .0479923
      HTR = 40. !transition altitude between zeeman region & lower atmosphere
      NM1 = N-1

c  READ ATMOSPHERE PROFILE
      OPEN(1,FILE='profile.dat',FORM='FORMATTED')
      DO I=1,N
       READ(1,1,end=3)  H(I),TEMP(I),PRES(I),RHO(I),O3NUM(I)
C atmospheric profile starting at surface:
C H(km), TEMP(K), PRES(mb), H2OvaporRHO(g/m**3), O3NUMdensity(molecules/m**3)
1      FORMAT(2F8.2,3E12.3)
       CLD(I) = 0.
       MXLV = I
      END DO
3     CLOSE(1)
      TS = TEMP(1)

C  READ PARAMETERS FOR THE CALCULATION
      WRITE(*,*) 'ENTER MAX.ALTITUDE (km), ANGLE FROM VERTICAL (deg)'
      READ(*,*) ALT,ANGLE
      CTHN = -COS(ANGLE/57.296)
      SECANT1 = -1./CTHN
      SECANT2 = SECANT1  !assume specular reflection
      BFIELD = 0.
      IF(ALT.GT.HTR) THEN
        WRITE(*,*) 'ENTER AZIMUTH ANGLE OF PROPAGATION',
     &   ' (deg from north toward east)'
        READ(*,*) PHI
        WRITE(*,*) 'ENTER B-FIELD COMPONENTS:',
     & ' NORTHWARD,EASTWARD,DOWNWARD (gauss)'
        READ(*,*) BVEC
        CALL E2ROT(CTHN,PHI,BVEC,PHASEROTFAC,CBTH,BFIELD)
          write(*,*) phaserotfac,cbth,bfield
      ENDIF
      WRITE(*,*) 'ENTER FREQUENCY LIMITS (GHz): lower,upper'
      READ(*,*) F1,F2
      IF(F2.LE.F1) STOP
      DF = (F2-F1)/100.
      TBMIN = 500.
      TBMAX = 0.
      VINT = 0.
c  find indices corresponding to HTR and ALT
      DO I=2,MXLV
       NLVA = I
       IF(H(I).LE.HTR) NLVTR = I
       VINT = VINT + (RHO(I-1)+RHO(I))*(H(I)-H(I-1))/2.
       IF(H(I).GE.ALT) GOTO 10
      END DO
10    CONTINUE
      OPEN(2,FILE='spectrum.out',FORM='FORMATTED')
      WRITE(2,*) ALT,' km ',ANGLE,' deg. ',VINT,' mm H2O ',
     & BFIELD,' gauss'
      WRITE(2,*) '      freq     TBv         TBh',
     & '         TBlin            TBrc         TBlc'

      DO 30 J=1,M  !frequency loop
       FREQ = F1 + (J-1)*DF
       efac = exp(rcons*freq/2.73)
C including zero-point fluctuation in cosmic background compensates
C for non-linearity of Planck function
       TBC = .5*rcons*freq*(efac+1.)/(efac-1.)
       F(J) = FREQ
       JU = 0
       IF(ALT.GT.HTR) CALL FINDLINE(FREQ,0.03,JU,DELF)
       ZCALC = JU.GT.0
C
C  Scalar propagation
       IF(ZCALC) THEN
        NLV = NLVTR
       ELSE
        NLV = NLVA
       ENDIF
c   Although TBARRAY2 can compute for multiple angles
c   and frequencies, it's used 1 freq at a time here, for compatibility
c   with the Zeeman routines.
       CALL TBARRAY2(NLV,H,TEMP,PRES,RHO,CLD,O3NUM,1,SECANT1,SECANT2,
     & 1,FREQ,TB1,TB2,E1,E2,OPACITY)
       CALL DILEC10(EC,FREQ,TS,.035)
       CALL REF(RH,RV,EC,ANGLE)
       TBv(J) = TB2 + E2*((1.-Rv)*Ts + Rv*(TB1 + E1*TBc)) !vert.pol.
       TBh(J) = TB2 + E2*((1.-Rh)*Ts + Rh*(TB1 + E1*TBc)) !horiz.pol.
       TBlc(J) = (TBv(J)+TBh(J))/2.   !circ.pol.
       TBrc(J) = TBlc(J)
       TBLIN = (TBv(J) - TBh(J))/2.

       IF(ZCALC) THEN ! Polarized propagation
c   rotate phase to plane of B-field
        TBLIN = TBLIN*CONJG(PHASEROTFAC)
        DO  I=NLV,NM1 !altitude loop
         IF(H(I+1).GT.ALT) GOTO 20
         TAV = (TEMP(I) + TEMP(I+1))/2.
         PAV = SQRT(PRES(I)*PRES(I+1))
         DS = (H(I+1)-H(I))*SECANT1
         CALL O2ABSZ(TAV,PAV,FREQ,BFIELD,JU,ALPHA,GM,GPI,GP)
         CALL TBMX(TBRC(J),TBLC(J),TBLIN,DS,TAV,ALPHA,GP,GM,GPI,CBTH)
        END DO
20      CONTINUE
C  rotate phase back to V-pol plane. note that TBv and TBh may be correlated
        TBLIN = TBLIN*PHASEROTFAC
        TBv(J) = (TBRC(J)+TBLC(J))/2. + REAL(TBLIN)
        TBh(J) = TBv(J) - 2.*REAL(TBLIN)
       ENDIF

25     TBMIN = AMIN1(TBMIN,TBv(J),TBh(J),TBRC(J),TBLC(J))
       TBMAX = AMAX1(TBMAX,TBv(J),TBh(J),TBRC(J),TBLC(J))
       WRITE(2,2) FREQ,TBv(J),TBh(J),TBLIN,TBRC(J),TBLC(J)
2      FORMAT(7F11.4)
30    CONTINUE
      CLOSE(2)

C  PLOT TB CURVES
      DELTB = (TBMAX-TBMIN)/10.
      OPEN(3,FILE='test_up.eps',STATUS='unknown',FORM='formatted')
      CALL LINLIN(3,'FREQUENCY, GHz?',F1,5,20.*DF,80.,1,'(F7.3)',
     & 'BRIGHTNESS TEMPERATURE, K?',TBMIN,10,DELTB,40.,1,'(F7.2)')
      CALL PLOTLINE(F,TBh,M,2)
      CALL PLOTLINE(F,TBv,M,1)
      IF(ZCALC) THEN
       CALL PLOTLINE(F,TBRC,M,0)
       CALL PLOTLINE(F,TBLC,M,4)
      ENDIF
      CALL ENDGRAPH
      END

